==> blowing-bubbles-1.0.1-sources.jar: net/nml/bubble/PopParticle.java <==
package net.nml.bubble;

import net.minecraft.class_3999;
import net.minecraft.class_4002;
import net.minecraft.class_4003;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.joml.Vector3f;

public class PopParticle extends class_4003 {
	private final class_4002 spriteProvider;

	PopParticle(class_638 clientWorld, double x, double y, double z, PopParticleEffect parameters, class_4002 spriteProvider) {
		super(clientWorld, x, y, z);
		this.spriteProvider = spriteProvider;
		this.field_17867 = (parameters.getScale() - 0.5f) * (this.field_3840.method_43057() * 0.4F + 0.8F) * 0.5f;
		this.field_3847 = 3;
		this.method_18142(spriteProvider);
		Vector3f color = parameters.getColor();
		this.field_3861 = color.x();
		this.field_3842 = color.y();
		this.field_3859 = color.z();
	}

	@Override
	public void method_3070() {
		this.field_3858 = this.field_3874;
		this.field_3838 = this.field_3854;
		this.field_3856 = this.field_3871;
		if (this.field_3866++ >= this.field_3847) {
			this.method_3085();
		} else {
			this.method_18142(this.spriteProvider);
		}
	}

	@Override
	public class_3999 method_18122() {
		return class_3999.field_17828;
	}

	public static class Factory implements class_707<PopParticleEffect> {
		private final class_4002 spriteProvider;

		public Factory(class_4002 spriteProvider) {
			this.spriteProvider = spriteProvider;
		}

		@Override
		public class_703 createParticle(PopParticleEffect parameters, class_638 world, double x, double y, double z, double velocityX, double velocityY, double velocityZ) {
			return new PopParticle(world, x, y, z, parameters, this.spriteProvider);
		}
	}
	
}

==> blowing-bubbles-1.0.3-sources.jar: net/nml/bubble/PopParticle.java <==
package net.nml.bubble;

import net.minecraft.class_3940;
import net.minecraft.class_4002;
import net.minecraft.class_5819;
import net.minecraft.class_638;
import net.minecraft.class_703;
import net.minecraft.class_707;
import org.joml.Vector3f;

public class PopParticle extends class_3940 {
	private final class_4002 spriteProvider;

	PopParticle(class_638 clientWorld, double x, double y, double z, PopParticleEffect parameters, class_4002 spriteProvider) {
		super(clientWorld, x, y, z, spriteProvider.method_74304());
		this.spriteProvider = spriteProvider;
		this.field_17867 = (parameters.getScale() - 0.5f) * (this.field_3840.method_43057() * 0.4F + 0.8F) * 0.5f;
		this.field_3847 = 3;
		this.method_74306(spriteProvider);
		Vector3f color = parameters.getColor();
		this.field_62633 = color.x();
		this.field_62634 = color.y();
		this.field_62635 = color.z();
	}

	@Override
	public void method_3070() {
		this.field_3858 = this.field_3874;
		this.field_3838 = this.field_3854;
		this.field_3856 = this.field_3871;
		if (this.field_3866++ >= this.field_3847) {
			this.method_3085();
		} else {
			this.method_74306(this.spriteProvider);
		}
	}

	@Override
	protected class_11941 method_74255() {
		return class_3940.class_11941.field_62640;
	}

	public static class Factory implements class_707<PopParticleEffect> {
		private final class_4002 spriteProvider;

		public Factory(class_4002 spriteProvider) {
			this.spriteProvider = spriteProvider;
		}

		@Override
		public class_703 createParticle(PopParticleEffect parameters, class_638 world, double x, double y, double z,
				double velocityX, double velocityY, double velocityZ, class_5819 random) {
			return new PopParticle(world, x, y, z, parameters, this.spriteProvider);
		}
	}
}
